@@ -1,4 +1,4 @@
-from pyg_sql._sql_table import sql_table, get_engine, sql_cursor, get_server, get_driver, create_schema, pd_to_sql, pd_read_sql
+from pyg_sql._sql_table import sql_table, sql_has_table, get_engine, sql_cursor, get_server, get_driver, create_schema, pd_to_sql, pd_read_sql
 from pyg_sql._sql_writer import sql_dumps, sql_loads, sql_write, sql_encode, sql_table_, sql_binary_store
 from pyg_sql._parse import sql_parse_path, sql_parse_table
 from pyg_sql._ts_writer import pd_write, pd_encode
